diff --git a/openslides/assignment/templates/assignment/poll_view.html b/openslides/assignment/templates/assignment/poll_view.html index 21ef5eb32..f170daeaf 100644 --- a/openslides/assignment/templates/assignment/poll_view.html +++ b/openslides/assignment/templates/assignment/poll_view.html @@ -16,8 +16,10 @@ {% trans "Back to election" %} {% if perms.projector.can_manage_projector %} - - + + {% endif %} diff --git a/openslides/assignment/templates/assignment/slide.html b/openslides/assignment/templates/assignment/slide.html index 39e633a04..93ffc00c1 100644 --- a/openslides/assignment/templates/assignment/slide.html +++ b/openslides/assignment/templates/assignment/slide.html @@ -41,8 +41,7 @@ {% if polls.exists %}
{% trans "Candidates" %} | {% for poll in polls %} @@ -51,10 +50,9 @@ {% endfor %}||
---|---|---|
+ | ||
{% if candidate in assignment.elected %} @@ -83,7 +81,7 @@ {% endfor %} | ||
{% trans 'Invalid votes' %} | {% for poll in polls %}@@ -100,7 +98,6 @@ {% trans 'Votes cast' %} | {% for poll in polls %} -
{% if poll.has_votes %}
diff --git a/openslides/motion/signals.py b/openslides/motion/signals.py
index fc218e363..b594b20ae 100644
--- a/openslides/motion/signals.py
+++ b/openslides/motion/signals.py
@@ -90,7 +90,7 @@ def setup_motion_config_page(sender, **kwargs):
name='motion_pdf_paragraph_numbering',
default_value=False,
form_field=forms.BooleanField(
- label=ugettext_lazy('Show paragraph numbering'),
+ label=ugettext_lazy('Show paragraph numbering (only in PDF)'),
required=False))
motion_allow_disable_versioning = ConfigVariable(
name='motion_allow_disable_versioning',
diff --git a/openslides/motion/urls.py b/openslides/motion/urls.py
index dbe919f99..b117dd7f6 100644
--- a/openslides/motion/urls.py
+++ b/openslides/motion/urls.py
@@ -31,8 +31,8 @@ urlpatterns = patterns('openslides.motion.views',
),
url(r'^(?P |
diff --git a/openslides/motion/models.py b/openslides/motion/models.py
index bb204c1d5..94c43c7d4 100644
--- a/openslides/motion/models.py
+++ b/openslides/motion/models.py
@@ -190,7 +190,7 @@ class Motion(SlideMixin, models.Model):
if link == 'view' or link == 'detail':
return reverse('motion_detail', args=[str(self.id)])
if link == 'update' or link == 'edit':
- return reverse('motion_edit', args=[str(self.id)])
+ return reverse('motion_update', args=[str(self.id)])
if link == 'delete':
return reverse('motion_delete', args=[str(self.id)])
return super(Motion, self).get_absolute_url(link)
@@ -725,15 +725,15 @@ class MotionPoll(RelatedModelMixin, CountInvalid, CountVotesCast, BasePoll):
"""Return a string, representing the poll."""
return _('Vote %d') % self.poll_number
- def get_absolute_url(self, link='edit'):
+ def get_absolute_url(self, link='update'):
"""
Return an URL for the poll.
The keyargument 'link' can be 'edit' or 'delete'.
"""
- if link == 'edit':
- return reverse('motion_poll_edit', args=[str(self.motion.pk),
- str(self.poll_number)])
+ if link == 'update':
+ return reverse('motion_poll_update', args=[str(self.motion.pk),
+ str(self.poll_number)])
if link == 'delete':
return reverse('motion_poll_delete', args=[str(self.motion.pk),
str(self.poll_number)])
@@ -725,15 +725,15 @@ class MotionPoll(RelatedModelMixin, CountInvalid, CountVotesCast, BasePoll):
"""
Return an URL for the poll.
- The keyargument 'link' can be 'edit' or 'delete'.
+ The keyargument 'link' can be 'update' or 'delete'.
"""